@@ -2,10 +2,8 @@
 
 """Tests debug-related functionality"""
 
-import pytest
-
 import python_pachyderm
-from tests import util
+from google.protobuf import duration_pb2
 
 
 def test_dump():
@@ -15,10 +13,9 @@ def test_dump():
         assert len(b) > 0
 
 
-@util.skip_if_below_pachyderm_version(1, 11, 2)
 def test_profile_cpu():
     client = python_pachyderm.Client()
-    for b in client.profile_cpu(python_pachyderm.Duration(seconds=1)):
+    for b in client.profile_cpu(duration_pb2.Duration(seconds=1)):
         assert isinstance(b, bytes)
         assert len(b) > 0
 
