@@ -5,24 +5,23 @@
 import pytest
 
 import python_pachyderm
+from python_pachyderm.proto.v2.pfs import pfs_pb2
+from python_pachyderm.proto.v2.transaction import transaction_pb2
 from tests import util
 
 
-@util.skip_if_below_pachyderm_version(1, 9, 10)
 def test_batch_transaction():
     client = python_pachyderm.Client()
-    expected_repo_count = len(client.list_repo()) + 3
+    expected_repo_count = len(list(client.list_repo())) + 3
 
     def create_repo_request():
-        return python_pachyderm.TransactionRequest(
-            create_repo=python_pachyderm.CreateRepoRequest(
-                repo=python_pachyderm.Repo(
-                    name=util.test_repo_name("test_batch_transaction")
-                )
+        return transaction_pb2.TransactionRequest(
+            create_repo=pfs_pb2.CreateRepoRequest(
+                repo=pfs_pb2.Repo(name=util.test_repo_name("test_batch_transaction"))
             )
         )
 
-    transaction = client.batch_transaction(
+    client.batch_transaction(
         [
             create_repo_request(),
             create_repo_request(),
@@ -31,13 +30,12 @@ def test_batch_transaction():
     )
 
     assert len(client.list_transaction()) == 0
-    assert len(client.list_repo()) == expected_repo_count
+    assert len(list(client.list_repo())) == expected_repo_count
 
 
-@util.skip_if_below_pachyderm_version(1, 9, 0)
 def test_transaction_context_mgr():
     client = python_pachyderm.Client()
-    expected_repo_count = len(client.list_repo()) + 2
+    expected_repo_count = len(list(client.list_repo())) + 2
 
     with client.transaction() as transaction:
         util.create_test_repo(client, "test_transaction_context_mgr")
@@ -52,43 +50,40 @@ def test_transaction_context_mgr():
         )
 
     assert len(client.list_transaction()) == 0
-    assert len(client.list_repo()) == expected_repo_count
+    assert len(list(client.list_repo())) == expected_repo_count
 
 
-@util.skip_if_below_pachyderm_version(1, 9, 0)
 def test_transaction_context_mgr_nested():
     client = python_pachyderm.Client()
 
-    with client.transaction() as transaction:
+    with client.transaction():
         assert client.transaction_id is not None
         old_transaction_id = client.transaction_id
 
-        with client.transaction() as transaction:
+        with client.transaction():
             assert client.transaction_id is not None
             assert client.transaction_id != old_transaction_id
 
         assert client.transaction_id == old_transaction_id
 
 
-@util.skip_if_below_pachyderm_version(1, 9, 0)
 def test_transaction_context_mgr_exception():
     client = python_pachyderm.Client()
-    expected_repo_count = len(client.list_repo())
+    expected_repo_count = len(list(client.list_repo()))
 
     with pytest.raises(Exception):
-        with client.transaction() as transaction:
+        with client.transaction():
             util.create_test_repo(client, "test_transaction_context_mgr_exception")
             util.create_test_repo(client, "test_transaction_context_mgr_exception")
             raise Exception("oops!")
 
     assert len(client.list_transaction()) == 0
-    assert len(client.list_repo()) == expected_repo_count
+    assert len(list(client.list_repo())) == expected_repo_count
 
 
-@util.skip_if_below_pachyderm_version(1, 9, 0)
 def test_delete_transaction():
     client = python_pachyderm.Client()
-    expected_repo_count = len(client.list_repo())
+    expected_repo_count = len(list(client.list_repo()))
 
     transaction = client.start_transaction()
     util.create_test_repo(client, "test_delete_transaction")
@@ -98,14 +93,13 @@ def test_delete_transaction():
     assert len(client.list_transaction()) == 0
     # even though the transaction was deleted, the repos were still created,
     # because the transaction wasn't tied to the client
-    assert len(client.list_repo()) == expected_repo_count + 2
+    assert len(list(client.list_repo())) == expected_repo_count + 2
 
     with pytest.raises(python_pachyderm.RpcError):
         # re-deleting should cause an error
         client.delete_transaction(transaction)
 
 
-@util.skip_if_below_pachyderm_version(1, 9, 0)
 def test_delete_all_transactions():
     client = python_pachyderm.Client()
     client.start_transaction()
